==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkChartXYZ.java <==
// java wrapper for vtkChartXYZ object
//

package vtk;
import vtk.*;

public class vtkChartXYZ extends vtkContextItem
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetAngle_2(double id0);
  public void SetAngle(double id0)
    { SetAngle_2(id0); }

  private native void SetAroundX_3(boolean id0);
  public void SetAroundX(boolean id0)
    { SetAroundX_3(id0); }

  private native void SetAnnotationLink_4(vtkAnnotationLink id0);
  public void SetAnnotationLink(vtkAnnotationLink id0)
    { SetAnnotationLink_4(id0); }

  private native long GetAxis_5(int id0);
  public vtkAxis GetAxis(int id0) {
    long temp = GetAxis_5(id0);

    if (temp == 0) return null;
    return (vtkAxis)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetAutoRotate_6(boolean id0);
  public void SetAutoRotate(boolean id0)
    { SetAutoRotate_6(id0); }

  private native void SetDecorateAxes_7(boolean id0);
  public void SetDecorateAxes(boolean id0)
    { SetDecorateAxes_7(id0); }

  private native void SetFitToScene_8(boolean id0);
  public void SetFitToScene(boolean id0)
    { SetFitToScene_8(id0); }

  private native void Update_9();
  public void Update()
    { Update_9(); }

  private native boolean Paint_10(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_10(id0); }

  private native int AddPlot_11(vtkPlot3D id0);
  public int AddPlot(vtkPlot3D id0)
    { return AddPlot_11(id0); }

  private native void ClearPlots_12();
  public void ClearPlots()
    { ClearPlots_12(); }

  private native void RecalculateBounds_13();
  public void RecalculateBounds()
    { RecalculateBounds_13(); }

  private native void RecalculateTransform_14();
  public void RecalculateTransform()
    { RecalculateTransform_14(); }

  public vtkChartXYZ() { super(); }

  public vtkChartXYZ(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkChartXYZ.java <==
// java wrapper for vtkChartXYZ object
//

package vtk;
import vtk.*;

public class vtkChartXYZ extends vtkContextItem
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetAngle_2(double id0);
  public void SetAngle(double id0)
    { SetAngle_2(id0); }

  private native void SetAroundX_3(boolean id0);
  public void SetAroundX(boolean id0)
    { SetAroundX_3(id0); }

  private native void SetAnnotationLink_4(vtkAnnotationLink id0);
  public void SetAnnotationLink(vtkAnnotationLink id0)
    { SetAnnotationLink_4(id0); }

  private native long GetAxis_5(int id0);
  public vtkAxis GetAxis(int id0) {
    long temp = GetAxis_5(id0);

    if (temp == 0) return null;
    return (vtkAxis)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetAxis_6(int id0,vtkAxis id1);
  public void SetAxis(int id0,vtkAxis id1)
    { SetAxis_6(id0,id1); }

  private native void SetAutoRotate_7(boolean id0);
  public void SetAutoRotate(boolean id0)
    { SetAutoRotate_7(id0); }

  private native void SetDecorateAxes_8(boolean id0);
  public void SetDecorateAxes(boolean id0)
    { SetDecorateAxes_8(id0); }

  private native void SetFitToScene_9(boolean id0);
  public void SetFitToScene(boolean id0)
    { SetFitToScene_9(id0); }

  private native void Update_10();
  public void Update()
    { Update_10(); }

  private native boolean Paint_11(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_11(id0); }

  private native int AddPlot_12(vtkPlot3D id0);
  public int AddPlot(vtkPlot3D id0)
    { return AddPlot_12(id0); }

  private native void ClearPlots_13();
  public void ClearPlots()
    { ClearPlots_13(); }

  private native void RecalculateBounds_14();
  public void RecalculateBounds()
    { RecalculateBounds_14(); }

  private native void RecalculateTransform_15();
  public void RecalculateTransform()
    { RecalculateTransform_15(); }

  public vtkChartXYZ() { super(); }

  public vtkChartXYZ(long id) { super(id); }
  public native long   VTKInit();

}
